SET NAMES utf8;
SET foreign_key_checks = 0;
SET time_zone = 'SYSTEM';

CREATE DATABASE `snidane` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `snidane`;

CREATE TABLE `clanky` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `nadpis` varchar(100) NOT NULL,
  `zmeneno` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

INSERT INTO `clanky` VALUES ('1', 'Úvod do PHP', '0000-00-00 00:00:00'), ('2', 'PHP a MySQL', '2009-06-03 10:29:32'), ('3', 'AJAX', '0000-00-00 00:00:00');

CREATE TABLE `clanky_ctenost` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `clanek_id` int(11) NOT NULL,
  `datum` date NOT NULL,
  `ctenost` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `clanek_id` (`clanek_id`,`datum`),
  CONSTRAINT `clanky_ctenost_ibfk_1` FOREIGN KEY (`clanek_id`) REFERENCES `clanky` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

CREATE TABLE `clanky_tagy` (
  `clanek_id` int(11) NOT NULL,
  `tag_id` int(11) NOT NULL,
  PRIMARY KEY (`clanek_id`,`tag_id`),
  KEY `tag_id` (`tag_id`),
  CONSTRAINT `clanky_tagy_ibfk_2` FOREIGN KEY (`tag_id`) REFERENCES `tagy` (`id`),
  CONSTRAINT `clanky_tagy_ibfk_1` FOREIGN KEY (`clanek_id`) REFERENCES `clanky` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `clanky_tagy` VALUES ('1', '1'), ('1', '2'), ('2', '2'), ('3', '3');

CREATE TABLE `diskuse` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `clanek_id` int(11) NOT NULL,
  `autor` varchar(50) NOT NULL,
  `zprava` text NOT NULL,
  PRIMARY KEY (`id`),
  KEY `clanek_id` (`clanek_id`),
  CONSTRAINT `diskuse_ibfk_1` FOREIGN KEY (`clanek_id`) REFERENCES `clanky` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

CREATE TRIGGER `diskuse_ai` AFTER INSERT ON `diskuse` FOR EACH ROW UPDATE clanky SET zmeneno = NOW() WHERE id = NEW.clanek_id;

INSERT INTO `diskuse` VALUES ('1', '2', '', 'Pokus');

CREATE TABLE `tagy` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `tag` varchar(20) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

INSERT INTO `tagy` VALUES ('1', 'php'), ('2', 'mysql'), ('3', 'javascript');

CREATE VIEW clanky_s_tagy AS
SELECT clanky.*, GROUP_CONCAT(tagy.tag) AS tagy
FROM clanky
LEFT JOIN clanky_tagy ON clanky.id = clanky_tagy.clanek_id
LEFT JOIN tagy ON clanky_tagy.tag_id = tagy.id
GROUP BY clanky.id;

INSERT INTO clanky_ctenost (clanek_id, datum, ctenost)
VALUES (1, CURDATE(), 1)
ON DUPLICATE KEY UPDATE ctenost = ctenost + 1;
